//
//  WPKSetup.h
//  KSCrash-iOS
//
//  Created by xc on 2019/3/8.
//  Copyright © 2019 Karl Stenerud. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, WPKCrashType)
{
    /* Captures and reports Mach exceptions. */
    WPKCrashTypeMachException      = 0x01,
    
    /* Captures and reports POSIX signals. */
    WPKCrashTypeSignal             = 0x02,
    
    /* Captures and reports C++ exceptions.
     * Note: This will slightly slow down exception processing.
     */
    WPKCrashTypeCPPException       = 0x04,
    
    /* Captures and reports NSExceptions. */
    WPKCrashTypeNSException        = 0x08,
    
    /* Detects and reports a deadlock in the main thread. */
    WPKCrashTypeMainThreadDeadlock = 0x10,
    
    /* Accepts and reports user-generated exceptions. */
    WPKCrashTypeUserReported       = 0x20,
    
    /* Keeps track of and injects system information. */
    WPKCrashTypeSystem             = 0x40,
    
    /* Keeps track of and injects application state. */
    WPKCrashTypeApplicationState   = 0x80,
    
    /* Keeps track of zombies, and injects the last zombie NSException. */
    WPKCrashTypeZombie             = 0x100,
};

typedef NSDictionary* (^WPKCrashCallback)(const char* crashUUID, WPKCrashType crashType, NSException *exception);

@interface WPKSetup : NSObject

/**
 *  初始化啄木鸟SDK
 *
 *  @param appName 啄木鸟应用分配的应用唯一标识
 */
+ (void)startWithAppName:(NSString *)appName;


/**
 *  初始化啄木鸟SDK
 *  @param appName 啄木鸟应用分配的应用唯一标识
 *  @param buildData 自定义build号 (流水号, 用于兼容啄木鸟有流水号的app.)
 */
+ (void)startWithAppName:(NSString *)appName buildData:(NSString *)buildData;


/**
 *  初始化啄木鸟SDK
 *
 *  @param appName 啄木鸟应用分配的应用唯一标识
 *  @param applicationGroupIdentifier 设置 App Group Identifier (如有使用 App Extension SDK，请务必设置该值)
 */
+ (void)startWithAppName:(NSString *)appName applicationGroupIdentifier:(NSString *)applicationGroupIdentifier;


/**
 *  初始化啄木鸟SDK
 *
 *  @param appName 啄木鸟应用分配的应用唯一标识
 *  @param applicationGroupIdentifier 设置 App Group Identifier (如有使用 App Extension SDK，请务必设置该值)
 */
+ (void)startWithAppName:(NSString *)appName buildData:(NSString *)buildData applicationGroupIdentifier:(NSString *)applicationGroupIdentifier;


/**
 *  设置用户标识
 *
 *  @param userId 用户标识, 推荐使用idfa, 如果外部不传入, 默认使用啄木鸟生成的userid(非idfa)
 */
+ (void)setUserIdentifier:(NSString *)userId;


/**
 *  设置用户自定义数据，随崩溃信息上报
 */
+ (void)setUserInfo:(NSDictionary *)userInfo;

/**
 *  设置自定义版本号 (需要在start的方法前调用)
 */
+ (void)setAppVersion:(NSString *)appVersion;

/**
 *  获取用户自定义数据
 */
+ (NSDictionary *)userInfo;


/**
 *  上传崩溃到服务器
 */
+ (void)sendAllReports;


/**
  使用啄木鸟的国际集群, 国际版app可以选择启动此开关
  默认为NO
 */
+ (void)useIntlServices:(BOOL)isIntl;

/**
 app崩溃时的回调
 这个回调中, 发起网络请求或者做异步的IO操作, 都可能发生不可预知的问题.
 return 的NSDictionary 将会以JSON格式附加到崩溃日志底部, 允许return nil;
 */
+ (void)setCrashCallback:(WPKCrashCallback)callback;

@end

NS_ASSUME_NONNULL_END
